@@ -1,19 +1,30 @@
 #include <zlib.h>
 #include <stdlib.h>
 
-z_stream * create_z_stream_inflate (int window_bits)
+z_stream * create_z_stream(void)
 {
 	z_stream *ret = malloc(sizeof(z_stream));
-	ret->zalloc = Z_NULL;
-	ret->zfree = Z_NULL;
-	ret->opaque = Z_NULL;
-	ret->next_in = NULL;
-	ret->avail_in = 0;
+	if (ret) {
+		ret->zalloc = Z_NULL;
+		ret->zfree = Z_NULL;
+		ret->opaque = Z_NULL;
+		ret->next_in = NULL;
+		ret->avail_in = 0;
+		ret->next_out = NULL;
+		ret->avail_out = 0;
+	}
+	return ret;
+}
 
-	if (inflateInit2(ret, window_bits) != Z_OK)
-	    return NULL;
-	else
-	    return ret;
+int inflate_init2(z_stream *stream, int window_bits)
+{
+	return inflateInit2(stream, window_bits);
+}
+
+int deflate_init2(z_stream *stream, int level, int methodBits,
+                  int memlevel, int strategy)
+{
+	return deflateInit2(stream, level, Z_DEFLATED, methodBits, memlevel, strategy);
 }
 
 void free_z_stream_inflate (z_stream *stream)
@@ -49,26 +60,6 @@ unsigned int get_avail_out (z_stream *stream)
 	return stream->avail_out;
 }
 
-z_stream * create_z_stream_deflate (int level, int window_bits)
-{
-	z_stream *ret = malloc(sizeof(z_stream));
-	ret->zalloc = Z_NULL;
-	ret->zfree = Z_NULL;
-	ret->opaque = Z_NULL;
-	ret->next_in = NULL;
-	ret->avail_in = 0;
-
-	if (deflateInit2(ret,
-			 level,
-			 Z_DEFLATED,
-			 window_bits,
-			 8,
-			 Z_DEFAULT_STRATEGY)
-		!= Z_OK)                 return NULL;
-	else
-	    return ret;
-}
-
 void free_z_stream_deflate (z_stream *stream)
 {
 	deflateEnd(stream);
